# -*- coding: utf-8 -*-
# **************************************************************************
# *
# * Authors:     Scipion Team
# *
# * National Center of Biotechnology, CSIC, Spain
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from os.path import abspath

from pwem.emlib.image import ImageHandler
from pyworkflow.utils import replaceExt, getExt

COMP_EXT_MASK_LIST = ['.mrc', '.em', '.rec']


def encodePresegArea(areaIndex):
    """EnumParam in form goes from 0 to 2 for the preseg areas codification, while
    Pyseg expects values higher or equal to 1, because 0 is used for the backgrounf"""
    return int(areaIndex) + 1


def getFinalMaskFileName(inMask):
    if getExt(inMask.getFileName()) in COMP_EXT_MASK_LIST:
        return abspath(inMask.getFileName())
    else:
        return abspath(replaceExt(inMask.getFileName(), '.mrc'))


def checkMaskFormat(inMask):
    if getExt(inMask.getFileName()) not in COMP_EXT_MASK_LIST:
        ih = ImageHandler()
        ih.convert(inMask.getFileName(), getFinalMaskFileName(inMask))
